==> aliyun-python-sdk-live-3.9.10.tar.gz: aliyun-python-sdk-live-3.9.10/aliyunsdklive/request/v20161101/CreateMixStreamRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdklive.endpoint import endpoint_data

class CreateMixStreamRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'live', '2016-11-01', 'CreateMixStream','live')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_OutputConfig(self):
		return self.get_query_params().get('OutputConfig')

	def set_OutputConfig(self,OutputConfig):
		self.add_query_param('OutputConfig',OutputConfig)

	def get_LayoutId(self):
		return self.get_query_params().get('LayoutId')

	def set_LayoutId(self,LayoutId):
		self.add_query_param('LayoutId',LayoutId)

	def get_DomainName(self):
		return self.get_query_params().get('DomainName')

	def set_DomainName(self,DomainName):
		self.add_query_param('DomainName',DomainName)

	def get_InputStreamList(self):
		return self.get_query_params().get('InputStreamList')

	def set_InputStreamList(self,InputStreamList):
		self.add_query_param('InputStreamList',InputStreamList)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_CallbackConfig(self):
		return self.get_query_params().get('CallbackConfig')

	def set_CallbackConfig(self,CallbackConfig):
		self.add_query_param('CallbackConfig',CallbackConfig)

==> aliyun-python-sdk-live-3.9.44.tar.gz: aliyun-python-sdk-live-3.9.44/aliyunsdklive/request/v20161101/CreateMixStreamRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdklive.endpoint import endpoint_data

class CreateMixStreamRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'live', '2016-11-01', 'CreateMixStream','live')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_OutputConfig(self): # String
		return self.get_query_params().get('OutputConfig')

	def set_OutputConfig(self, OutputConfig):  # String
		self.add_query_param('OutputConfig', OutputConfig)
	def get_LayoutId(self): # String
		return self.get_query_params().get('LayoutId')

	def set_LayoutId(self, LayoutId):  # String
		self.add_query_param('LayoutId', LayoutId)
	def get_DomainName(self): # String
		return self.get_query_params().get('DomainName')

	def set_DomainName(self, DomainName):  # String
		self.add_query_param('DomainName', DomainName)
	def get_InputStreamList(self): # String
		return self.get_query_params().get('InputStreamList')

	def set_InputStreamList(self, InputStreamList):  # String
		self.add_query_param('InputStreamList', InputStreamList)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_CallbackConfig(self): # String
		return self.get_query_params().get('CallbackConfig')

	def set_CallbackConfig(self, CallbackConfig):  # String
		self.add_query_param('CallbackConfig', CallbackConfig)
